@@ -46,7 +46,7 @@ import datetime
 import discord.abc
 from .scheduled_event import ScheduledEvent
 from .permissions import PermissionOverwrite, Permissions
-from .enums import ChannelType, PrivacyLevel, try_enum, VideoQualityMode, EntityType
+from .enums import ChannelType, PrivacyLevel, try_enum, VideoQualityMode
 from .mixins import Hashable
 from . import utils
 from .utils import MISSING
@@ -216,10 +216,6 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
     def _sorting_bucket(self) -> int:
         return ChannelType.text.value
 
-    @property
-    def _scheduled_event_entity_type(self) -> Optional[EntityType]:
-        return None
-
     @utils.copy_doc(discord.abc.GuildChannel.permissions_for)
     def permissions_for(self, obj: Union[Member, Role], /) -> Permissions:
         base = super().permissions_for(obj)
@@ -1049,10 +1045,6 @@ class VoiceChannel(discord.abc.Messageable, VocalGuildChannel):
     async def _get_channel(self) -> Self:
         return self
 
-    @property
-    def _scheduled_event_entity_type(self) -> Optional[EntityType]:
-        return EntityType.voice
-
     @property
     def type(self) -> Literal[ChannelType.voice]:
         """:class:`ChannelType`: The channel's Discord type."""
@@ -1488,10 +1480,6 @@ class StageChannel(VocalGuildChannel):
         super()._update(guild, data)
         self.topic: Optional[str] = data.get('topic')
 
-    @property
-    def _scheduled_event_entity_type(self) -> Optional[EntityType]:
-        return EntityType.stage_instance
-
     @property
     def requesting_to_speak(self) -> List[Member]:
         """List[:class:`Member`]: A list of members who are requesting to speak in the stage channel."""
@@ -1770,10 +1758,6 @@ class CategoryChannel(discord.abc.GuildChannel, Hashable):
     def _sorting_bucket(self) -> int:
         return ChannelType.category.value
 
-    @property
-    def _scheduled_event_entity_type(self) -> Optional[EntityType]:
-        return None
-
     @property
     def type(self) -> Literal[ChannelType.category]:
         """:class:`ChannelType`: The channel's Discord type."""
@@ -2050,10 +2034,6 @@ class ForumChannel(discord.abc.GuildChannel, Hashable):
     def _sorting_bucket(self) -> int:
         return ChannelType.text.value
 
-    @property
-    def _scheduled_event_entity_type(self) -> Optional[EntityType]:
-        return None
-
     @utils.copy_doc(discord.abc.GuildChannel.permissions_for)
     def permissions_for(self, obj: Union[Member, Role], /) -> Permissions:
         base = super().permissions_for(obj)
@@ -2305,67 +2285,6 @@ class ForumChannel(discord.abc.GuildChannel, Hashable):
 
             return ThreadWithMessage(thread=thread, message=message)
 
-    async def webhooks(self) -> List[Webhook]:
-        """|coro|
-
-        Gets the list of webhooks from this channel.
-
-        Requires :attr:`~.Permissions.manage_webhooks` permissions.
-
-        Raises
-        -------
-        Forbidden
-            You don't have permissions to get the webhooks.
-
-        Returns
-        --------
-        List[:class:`Webhook`]
-            The webhooks for this channel.
-        """
-
-        from .webhook import Webhook
-
-        data = await self._state.http.channel_webhooks(self.id)
-        return [Webhook.from_state(d, state=self._state) for d in data]
-
-    async def create_webhook(self, *, name: str, avatar: Optional[bytes] = None, reason: Optional[str] = None) -> Webhook:
-        """|coro|
-
-        Creates a webhook for this channel.
-
-        Requires :attr:`~.Permissions.manage_webhooks` permissions.
-
-        Parameters
-        -------------
-        name: :class:`str`
-            The webhook's name.
-        avatar: Optional[:class:`bytes`]
-            A :term:`py:bytes-like object` representing the webhook's default avatar.
-            This operates similarly to :meth:`~ClientUser.edit`.
-        reason: Optional[:class:`str`]
-            The reason for creating this webhook. Shows up in the audit logs.
-
-        Raises
-        -------
-        HTTPException
-            Creating the webhook failed.
-        Forbidden
-            You do not have permissions to create a webhook.
-
-        Returns
-        --------
-        :class:`Webhook`
-            The created webhook.
-        """
-
-        from .webhook import Webhook
-
-        if avatar is not None:
-            avatar = utils._bytes_to_base64_data(avatar)  # type: ignore # Silence reassignment error
-
-        data = await self._state.http.create_webhook(self.id, name=str(name), avatar=avatar, reason=reason)
-        return Webhook.from_state(data, state=self._state)
-
 
 class DMChannel(discord.abc.Messageable, Hashable):
     """Represents a Discord direct message channel.
